# LiveKit Plugins Azure

Agent Framework plugin for services from Azure Cognitive Services. Currently supports STT and TTS.

## Installation

```bash
pip install livekit-plugins-azure
```

## Pre-requisites

You'll need to specify an Azure Speech Key and a Deployment Region. They can be set as environment variables: `AZURE_SPEECH_KEY` and `AZURE_SPEECH_REGION`, respectively.
